# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class CodeItem(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    商品情報
    """


    class MetaOapg:
        required = {
            "price",
            "count",
            "name",
        }
        
        class properties:
            name = schemas.StrSchema
            price = schemas.IntSchema
            count = schemas.IntSchema
            
            
            class image(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    regex=[{
                        'pattern': r'https?://[-A-Za-z0-9+&@#/%?=~_|!:,.;]+[-A-Za-z0-9+&@#/%=~_|]',  # noqa: E501
                    }]
            __annotations__ = {
                "name": name,
                "price": price,
                "count": count,
                "image": image,
            }
    
    price: MetaOapg.properties.price
    count: MetaOapg.properties.count
    name: MetaOapg.properties.name
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["price"]) -> MetaOapg.properties.price: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["count"]) -> MetaOapg.properties.count: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["image"]) -> MetaOapg.properties.image: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "price", "count", "image", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["price"]) -> MetaOapg.properties.price: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["count"]) -> MetaOapg.properties.count: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["image"]) -> typing.Union[MetaOapg.properties.image, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "price", "count", "image", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        price: typing.Union[MetaOapg.properties.price, decimal.Decimal, int, ],
        count: typing.Union[MetaOapg.properties.count, decimal.Decimal, int, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        image: typing.Union[MetaOapg.properties.image, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CodeItem':
        return super().__new__(
            cls,
            *args,
            price=price,
            count=count,
            name=name,
            image=image,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

import unittest

import elepay
from elepay.model.location_dto import LocationDto
from elepay import configuration


class TestLocationDto(unittest.TestCase):
    """LocationDto unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class SortOrderType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    ソート順
    """


    class MetaOapg:
        enum_value_to_name = {
            "desc": "DESC",
            "asc": "ASC",
        }
    
    @schemas.classproperty
    def DESC(cls):
        return cls("desc")
    
    @schemas.classproperty
    def ASC(cls):
        return cls("asc")



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class ResourceType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    決済リソース
- web WEBブラウザ
- ios iOS Nativeアプリ
- android Android Nativeアプリ
- liff Line LIFFアプリ
- mini WeChatミニプログラム
- cpm CPM決済、利用者提示型QRコード
- mpm MPM決済、店舗側提示型QRコード
- reader カードリーダー決済(リーダー設備が必要)

    """


    class MetaOapg:
        enum_value_to_name = {
            "web": "WEB",
            "ios": "IOS",
            "android": "ANDROID",
            "liff": "LIFF",
            "mini": "MINI",
            "cpm": "CPM",
            "mpm": "MPM",
            "reader": "READER",
        }
    
    @schemas.classproperty
    def WEB(cls):
        return cls("web")
    
    @schemas.classproperty
    def IOS(cls):
        return cls("ios")
    
    @schemas.classproperty
    def ANDROID(cls):
        return cls("android")
    
    @schemas.classproperty
    def LIFF(cls):
        return cls("liff")
    
    @schemas.classproperty
    def MINI(cls):
        return cls("mini")
    
    @schemas.classproperty
    def CPM(cls):
        return cls("cpm")
    
    @schemas.classproperty
    def MPM(cls):
        return cls("mpm")
    
    @schemas.classproperty
    def READER(cls):
        return cls("reader")



from elepay.paths.terminal_readers_reader_id.get import ApiForget
from elepay.paths.terminal_readers_reader_id.delete import ApiFordelete


class TerminalReadersReaderId(
    ApiForget,
    ApiFordelete,
):
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from elepay.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    CHARGE = "Charge"
    REFUND = "Refund"
    CUSTOMER = "Customer"
    CODE = "Code"
    CODE_SETTING = "CodeSetting"
    PAYMENT_METHOD = "PaymentMethod"
    TERMINAL = "Terminal"
    INVOICE = "Invoice"
    DISPUTE = "Dispute"
    SUBSCRIPTION = "Subscription"



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class SourceDto(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    カスタマソースオブジェクト
    """


    class MetaOapg:
        
        class properties:
            id = schemas.StrSchema
            object = schemas.StrSchema
            liveMode = schemas.BoolSchema
        
            @staticmethod
            def paymentMethod() -> typing.Type['PaymentMethodType']:
                return PaymentMethodType
        
            @staticmethod
            def resource() -> typing.Type['ResourceType']:
                return ResourceType
            description = schemas.StrSchema
            
            
            class extra(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'extra':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class info(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.DictSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, ],
                ) -> 'info':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
        
            @staticmethod
            def cardInfo() -> typing.Type['CardInfo']:
                return CardInfo
            
            
            class metadata(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'metadata':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            credential = schemas.StrSchema
        
            @staticmethod
            def status() -> typing.Type['SourceStatusType']:
                return SourceStatusType
            __annotations__ = {
                "id": id,
                "object": object,
                "liveMode": liveMode,
                "paymentMethod": paymentMethod,
                "resource": resource,
                "description": description,
                "extra": extra,
                "info": info,
                "cardInfo": cardInfo,
                "metadata": metadata,
                "credential": credential,
                "status": status,
            }

    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["object"]) -> MetaOapg.properties.object: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["liveMode"]) -> MetaOapg.properties.liveMode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paymentMethod"]) -> 'PaymentMethodType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["resource"]) -> 'ResourceType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["extra"]) -> MetaOapg.properties.extra: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["info"]) -> MetaOapg.properties.info: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["cardInfo"]) -> 'CardInfo': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["credential"]) -> MetaOapg.properties.credential: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'SourceStatusType': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "object", "liveMode", "paymentMethod", "resource", "description", "extra", "info", "cardInfo", "metadata", "credential", "status", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["object"]) -> typing.Union[MetaOapg.properties.object, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["liveMode"]) -> typing.Union[MetaOapg.properties.liveMode, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paymentMethod"]) -> typing.Union['PaymentMethodType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["resource"]) -> typing.Union['ResourceType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["extra"]) -> typing.Union[MetaOapg.properties.extra, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["info"]) -> typing.Union[MetaOapg.properties.info, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["cardInfo"]) -> typing.Union['CardInfo', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["credential"]) -> typing.Union[MetaOapg.properties.credential, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union['SourceStatusType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "object", "liveMode", "paymentMethod", "resource", "description", "extra", "info", "cardInfo", "metadata", "credential", "status", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
        object: typing.Union[MetaOapg.properties.object, str, schemas.Unset] = schemas.unset,
        liveMode: typing.Union[MetaOapg.properties.liveMode, bool, schemas.Unset] = schemas.unset,
        paymentMethod: typing.Union['PaymentMethodType', schemas.Unset] = schemas.unset,
        resource: typing.Union['ResourceType', schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        extra: typing.Union[MetaOapg.properties.extra, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        info: typing.Union[MetaOapg.properties.info, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        cardInfo: typing.Union['CardInfo', schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        credential: typing.Union[MetaOapg.properties.credential, str, schemas.Unset] = schemas.unset,
        status: typing.Union['SourceStatusType', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SourceDto':
        return super().__new__(
            cls,
            *args,
            id=id,
            object=object,
            liveMode=liveMode,
            paymentMethod=paymentMethod,
            resource=resource,
            description=description,
            extra=extra,
            info=info,
            cardInfo=cardInfo,
            metadata=metadata,
            credential=credential,
            status=status,
            _configuration=_configuration,
            **kwargs,
        )

from elepay.model.card_info import CardInfo
from elepay.model.payment_method_type import PaymentMethodType
from elepay.model.resource_type import ResourceType
from elepay.model.source_status_type import SourceStatusType



from elepay.paths.customers_customer_id.get import ApiForget
from elepay.paths.customers_customer_id.post import ApiForpost
from elepay.paths.customers_customer_id.delete import ApiFordelete


class CustomersCustomerId(
    ApiForget,
    ApiForpost,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class CardInfo(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    カード情報やウォレット情報
    """


    class MetaOapg:
        
        class properties:
        
            @staticmethod
            def brand() -> typing.Type['CardBrandType']:
                return CardBrandType
            last4 = schemas.StrSchema
            expMonth = schemas.IntSchema
            expYear = schemas.IntSchema
            name = schemas.StrSchema
            wallet = schemas.StrSchema
            threeDSecure = schemas.BoolSchema
            threeDSecureVersion = schemas.StrSchema
            __annotations__ = {
                "brand": brand,
                "last4": last4,
                "expMonth": expMonth,
                "expYear": expYear,
                "name": name,
                "wallet": wallet,
                "threeDSecure": threeDSecure,
                "threeDSecureVersion": threeDSecureVersion,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["brand"]) -> 'CardBrandType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last4"]) -> MetaOapg.properties.last4: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expMonth"]) -> MetaOapg.properties.expMonth: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expYear"]) -> MetaOapg.properties.expYear: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["wallet"]) -> MetaOapg.properties.wallet: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["threeDSecure"]) -> MetaOapg.properties.threeDSecure: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["threeDSecureVersion"]) -> MetaOapg.properties.threeDSecureVersion: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["brand", "last4", "expMonth", "expYear", "name", "wallet", "threeDSecure", "threeDSecureVersion", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["brand"]) -> typing.Union['CardBrandType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last4"]) -> typing.Union[MetaOapg.properties.last4, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expMonth"]) -> typing.Union[MetaOapg.properties.expMonth, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expYear"]) -> typing.Union[MetaOapg.properties.expYear, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["wallet"]) -> typing.Union[MetaOapg.properties.wallet, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["threeDSecure"]) -> typing.Union[MetaOapg.properties.threeDSecure, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["threeDSecureVersion"]) -> typing.Union[MetaOapg.properties.threeDSecureVersion, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["brand", "last4", "expMonth", "expYear", "name", "wallet", "threeDSecure", "threeDSecureVersion", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        brand: typing.Union['CardBrandType', schemas.Unset] = schemas.unset,
        last4: typing.Union[MetaOapg.properties.last4, str, schemas.Unset] = schemas.unset,
        expMonth: typing.Union[MetaOapg.properties.expMonth, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        expYear: typing.Union[MetaOapg.properties.expYear, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
        wallet: typing.Union[MetaOapg.properties.wallet, str, schemas.Unset] = schemas.unset,
        threeDSecure: typing.Union[MetaOapg.properties.threeDSecure, bool, schemas.Unset] = schemas.unset,
        threeDSecureVersion: typing.Union[MetaOapg.properties.threeDSecureVersion, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CardInfo':
        return super().__new__(
            cls,
            *args,
            brand=brand,
            last4=last4,
            expMonth=expMonth,
            expYear=expYear,
            name=name,
            wallet=wallet,
            threeDSecure=threeDSecure,
            threeDSecureVersion=threeDSecureVersion,
            _configuration=_configuration,
            **kwargs,
        )

from elepay.model.card_brand_type import CardBrandType



import typing_extensions

from elepay.apis.tags import TagValues
from elepay.apis.tags.charge_api import ChargeApi
from elepay.apis.tags.refund_api import RefundApi
from elepay.apis.tags.customer_api import CustomerApi
from elepay.apis.tags.code_api import CodeApi
from elepay.apis.tags.code_setting_api import CodeSettingApi
from elepay.apis.tags.payment_method_api import PaymentMethodApi
from elepay.apis.tags.terminal_api import TerminalApi
from elepay.apis.tags.invoice_api import InvoiceApi
from elepay.apis.tags.dispute_api import DisputeApi
from elepay.apis.tags.subscription_api import SubscriptionApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.CHARGE: ChargeApi,
        TagValues.REFUND: RefundApi,
        TagValues.CUSTOMER: CustomerApi,
        TagValues.CODE: CodeApi,
        TagValues.CODE_SETTING: CodeSettingApi,
        TagValues.PAYMENT_METHOD: PaymentMethodApi,
        TagValues.TERMINAL: TerminalApi,
        TagValues.INVOICE: InvoiceApi,
        TagValues.DISPUTE: DisputeApi,
        TagValues.SUBSCRIPTION: SubscriptionApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.CHARGE: ChargeApi,
        TagValues.REFUND: RefundApi,
        TagValues.CUSTOMER: CustomerApi,
        TagValues.CODE: CodeApi,
        TagValues.CODE_SETTING: CodeSettingApi,
        TagValues.PAYMENT_METHOD: PaymentMethodApi,
        TagValues.TERMINAL: TerminalApi,
        TagValues.INVOICE: InvoiceApi,
        TagValues.DISPUTE: DisputeApi,
        TagValues.SUBSCRIPTION: SubscriptionApi,
    }
)



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from elepay.paths.subscriptions_subscription_id_cancel.post import CancelSubscription
from elepay.paths.subscriptions.post import CreateSubscription
from elepay.paths.subscriptions_subscription_id_periods.get import ListSubscriptionPeriods
from elepay.paths.subscriptions.get import ListSubscriptions
from elepay.paths.subscriptions_subscription_id_resume.post import ResumeSubscription
from elepay.paths.subscriptions_subscription_id.get import RetrieveSubscription
from elepay.paths.subscriptions_subscription_id_start.post import StartSubscription
from elepay.paths.subscriptions_subscription_id.post import UpdateSubscription


class SubscriptionApi(
    CancelSubscription,
    CreateSubscription,
    ListSubscriptionPeriods,
    ListSubscriptions,
    ResumeSubscription,
    RetrieveSubscription,
    StartSubscription,
    UpdateSubscription,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from elepay.paths.subscriptions_subscription_id.get import ApiForget
from elepay.paths.subscriptions_subscription_id.post import ApiForpost


class SubscriptionsSubscriptionId(
    ApiForget,
    ApiForpost,
):
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from elepay.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    CHARGES = "/charges"
    CHARGES_ID = "/charges/{id}"
    CHARGES_ID_REVOKE = "/charges/{id}/revoke"
    CHARGES_ID_CAPTURE = "/charges/{id}/capture"
    CHARGES_ID_STATUS = "/charges/{id}/status"
    CHARGES_ID_REFUNDS = "/charges/{id}/refunds"
    CHARGES_ID_REFUNDS_REFUND_ID = "/charges/{id}/refunds/{refundId}"
    CUSTOMERS = "/customers"
    CUSTOMERS_CUSTOMER_ID = "/customers/{customerId}"
    CUSTOMERS_CUSTOMER_ID_SOURCES = "/customers/{customerId}/sources"
    CUSTOMERS_CUSTOMER_ID_SOURCES_SOURCE_ID = "/customers/{customerId}/sources/{sourceId}"
    SOURCES_SOURCE_ID_STATUS = "/sources/{sourceId}/status"
    PAYMENTMETHODS = "/payment-methods"
    CODES = "/codes"
    CODES_CODE_ID = "/codes/{codeId}"
    CODESETTING_PAYMENTMETHODS = "/code-setting/payment-methods"
    INVOICES = "/invoices"
    INVOICES_INVOICE_ID = "/invoices/{invoiceId}"
    INVOICES_INVOICE_ID_CANCEL = "/invoices/{invoiceId}/cancel"
    INVOICES_INVOICE_ID_SUBMIT = "/invoices/{invoiceId}/submit"
    INVOICES_INVOICE_ID_SEND = "/invoices/{invoiceId}/send"
    TERMINAL_LOCATIONS = "/terminal/locations"
    TERMINAL_READERS = "/terminal/readers"
    TERMINAL_READERS_READER_ID = "/terminal/readers/{readerId}"
    DISPUTES = "/disputes"
    DISPUTES_ID = "/disputes/{id}"
    SUBSCRIPTIONS = "/subscriptions"
    SUBSCRIPTIONS_SUBSCRIPTION_ID = "/subscriptions/{subscriptionId}"
    SUBSCRIPTIONS_SUBSCRIPTION_ID_START = "/subscriptions/{subscriptionId}/start"
    SUBSCRIPTIONS_SUBSCRIPTION_ID_RESUME = "/subscriptions/{subscriptionId}/resume"
    SUBSCRIPTIONS_SUBSCRIPTION_ID_CANCEL = "/subscriptions/{subscriptionId}/cancel"
    SUBSCRIPTIONS_SUBSCRIPTION_ID_PERIODS = "/subscriptions/{subscriptionId}/periods"



from elepay.paths.customers_customer_id_sources_source_id.get import ApiForget
from elepay.paths.customers_customer_id_sources_source_id.delete import ApiFordelete


class CustomersCustomerIdSourcesSourceId(
    ApiForget,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class ChargeDto(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    支払いオブジェクト
    """


    class MetaOapg:
        
        class properties:
            id = schemas.StrSchema
            appId = schemas.StrSchema
            object = schemas.StrSchema
            liveMode = schemas.BoolSchema
            amount = schemas.IntSchema
            authorizeAmount = schemas.IntSchema
            currency = schemas.StrSchema
            authorize = schemas.BoolSchema
        
            @staticmethod
            def paymentMethod() -> typing.Type['PaymentMethodType']:
                return PaymentMethodType
        
            @staticmethod
            def resource() -> typing.Type['ResourceType']:
                return ResourceType
            orderNo = schemas.StrSchema
            description = schemas.StrSchema
            
            
            class extra(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'extra':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class metadata(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'metadata':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
        
            @staticmethod
            def cardInfo() -> typing.Type['CardInfo']:
                return CardInfo
            voucherNo = schemas.StrSchema
            clientIp = schemas.StrSchema
            paid = schemas.BoolSchema
            refunded = schemas.BoolSchema
            disputed = schemas.BoolSchema
        
            @staticmethod
            def refunds() -> typing.Type['RefundsDto']:
                return RefundsDto
        
            @staticmethod
            def status() -> typing.Type['ChargeStatusType']:
                return ChargeStatusType
            codeContent = schemas.StrSchema
            credential = schemas.StrSchema
            paidTime = schemas.Int64Schema
            refundTime = schemas.Int64Schema
            expiryTime = schemas.Int64Schema
            settleTime = schemas.Int64Schema
            createTime = schemas.Int64Schema
            __annotations__ = {
                "id": id,
                "appId": appId,
                "object": object,
                "liveMode": liveMode,
                "amount": amount,
                "authorizeAmount": authorizeAmount,
                "currency": currency,
                "authorize": authorize,
                "paymentMethod": paymentMethod,
                "resource": resource,
                "orderNo": orderNo,
                "description": description,
                "extra": extra,
                "metadata": metadata,
                "cardInfo": cardInfo,
                "voucherNo": voucherNo,
                "clientIp": clientIp,
                "paid": paid,
                "refunded": refunded,
                "disputed": disputed,
                "refunds": refunds,
                "status": status,
                "codeContent": codeContent,
                "credential": credential,
                "paidTime": paidTime,
                "refundTime": refundTime,
                "expiryTime": expiryTime,
                "settleTime": settleTime,
                "createTime": createTime,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["appId"]) -> MetaOapg.properties.appId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["object"]) -> MetaOapg.properties.object: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["liveMode"]) -> MetaOapg.properties.liveMode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["authorizeAmount"]) -> MetaOapg.properties.authorizeAmount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["authorize"]) -> MetaOapg.properties.authorize: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paymentMethod"]) -> 'PaymentMethodType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["resource"]) -> 'ResourceType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["orderNo"]) -> MetaOapg.properties.orderNo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["extra"]) -> MetaOapg.properties.extra: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["cardInfo"]) -> 'CardInfo': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["voucherNo"]) -> MetaOapg.properties.voucherNo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["clientIp"]) -> MetaOapg.properties.clientIp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paid"]) -> MetaOapg.properties.paid: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["refunded"]) -> MetaOapg.properties.refunded: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["disputed"]) -> MetaOapg.properties.disputed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["refunds"]) -> 'RefundsDto': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'ChargeStatusType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["codeContent"]) -> MetaOapg.properties.codeContent: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["credential"]) -> MetaOapg.properties.credential: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paidTime"]) -> MetaOapg.properties.paidTime: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["refundTime"]) -> MetaOapg.properties.refundTime: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expiryTime"]) -> MetaOapg.properties.expiryTime: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["settleTime"]) -> MetaOapg.properties.settleTime: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createTime"]) -> MetaOapg.properties.createTime: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "appId", "object", "liveMode", "amount", "authorizeAmount", "currency", "authorize", "paymentMethod", "resource", "orderNo", "description", "extra", "metadata", "cardInfo", "voucherNo", "clientIp", "paid", "refunded", "disputed", "refunds", "status", "codeContent", "credential", "paidTime", "refundTime", "expiryTime", "settleTime", "createTime", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["appId"]) -> typing.Union[MetaOapg.properties.appId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["object"]) -> typing.Union[MetaOapg.properties.object, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["liveMode"]) -> typing.Union[MetaOapg.properties.liveMode, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> typing.Union[MetaOapg.properties.amount, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["authorizeAmount"]) -> typing.Union[MetaOapg.properties.authorizeAmount, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> typing.Union[MetaOapg.properties.currency, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["authorize"]) -> typing.Union[MetaOapg.properties.authorize, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paymentMethod"]) -> typing.Union['PaymentMethodType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["resource"]) -> typing.Union['ResourceType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["orderNo"]) -> typing.Union[MetaOapg.properties.orderNo, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["extra"]) -> typing.Union[MetaOapg.properties.extra, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["cardInfo"]) -> typing.Union['CardInfo', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["voucherNo"]) -> typing.Union[MetaOapg.properties.voucherNo, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["clientIp"]) -> typing.Union[MetaOapg.properties.clientIp, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paid"]) -> typing.Union[MetaOapg.properties.paid, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["refunded"]) -> typing.Union[MetaOapg.properties.refunded, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["disputed"]) -> typing.Union[MetaOapg.properties.disputed, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["refunds"]) -> typing.Union['RefundsDto', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union['ChargeStatusType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["codeContent"]) -> typing.Union[MetaOapg.properties.codeContent, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["credential"]) -> typing.Union[MetaOapg.properties.credential, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paidTime"]) -> typing.Union[MetaOapg.properties.paidTime, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["refundTime"]) -> typing.Union[MetaOapg.properties.refundTime, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expiryTime"]) -> typing.Union[MetaOapg.properties.expiryTime, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["settleTime"]) -> typing.Union[MetaOapg.properties.settleTime, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createTime"]) -> typing.Union[MetaOapg.properties.createTime, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "appId", "object", "liveMode", "amount", "authorizeAmount", "currency", "authorize", "paymentMethod", "resource", "orderNo", "description", "extra", "metadata", "cardInfo", "voucherNo", "clientIp", "paid", "refunded", "disputed", "refunds", "status", "codeContent", "credential", "paidTime", "refundTime", "expiryTime", "settleTime", "createTime", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
        appId: typing.Union[MetaOapg.properties.appId, str, schemas.Unset] = schemas.unset,
        object: typing.Union[MetaOapg.properties.object, str, schemas.Unset] = schemas.unset,
        liveMode: typing.Union[MetaOapg.properties.liveMode, bool, schemas.Unset] = schemas.unset,
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        authorizeAmount: typing.Union[MetaOapg.properties.authorizeAmount, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        currency: typing.Union[MetaOapg.properties.currency, str, schemas.Unset] = schemas.unset,
        authorize: typing.Union[MetaOapg.properties.authorize, bool, schemas.Unset] = schemas.unset,
        paymentMethod: typing.Union['PaymentMethodType', schemas.Unset] = schemas.unset,
        resource: typing.Union['ResourceType', schemas.Unset] = schemas.unset,
        orderNo: typing.Union[MetaOapg.properties.orderNo, str, schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        extra: typing.Union[MetaOapg.properties.extra, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        cardInfo: typing.Union['CardInfo', schemas.Unset] = schemas.unset,
        voucherNo: typing.Union[MetaOapg.properties.voucherNo, str, schemas.Unset] = schemas.unset,
        clientIp: typing.Union[MetaOapg.properties.clientIp, str, schemas.Unset] = schemas.unset,
        paid: typing.Union[MetaOapg.properties.paid, bool, schemas.Unset] = schemas.unset,
        refunded: typing.Union[MetaOapg.properties.refunded, bool, schemas.Unset] = schemas.unset,
        disputed: typing.Union[MetaOapg.properties.disputed, bool, schemas.Unset] = schemas.unset,
        refunds: typing.Union['RefundsDto', schemas.Unset] = schemas.unset,
        status: typing.Union['ChargeStatusType', schemas.Unset] = schemas.unset,
        codeContent: typing.Union[MetaOapg.properties.codeContent, str, schemas.Unset] = schemas.unset,
        credential: typing.Union[MetaOapg.properties.credential, str, schemas.Unset] = schemas.unset,
        paidTime: typing.Union[MetaOapg.properties.paidTime, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        refundTime: typing.Union[MetaOapg.properties.refundTime, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        expiryTime: typing.Union[MetaOapg.properties.expiryTime, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        settleTime: typing.Union[MetaOapg.properties.settleTime, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        createTime: typing.Union[MetaOapg.properties.createTime, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ChargeDto':
        return super().__new__(
            cls,
            *args,
            id=id,
            appId=appId,
            object=object,
            liveMode=liveMode,
            amount=amount,
            authorizeAmount=authorizeAmount,
            currency=currency,
            authorize=authorize,
            paymentMethod=paymentMethod,
            resource=resource,
            orderNo=orderNo,
            description=description,
            extra=extra,
            metadata=metadata,
            cardInfo=cardInfo,
            voucherNo=voucherNo,
            clientIp=clientIp,
            paid=paid,
            refunded=refunded,
            disputed=disputed,
            refunds=refunds,
            status=status,
            codeContent=codeContent,
            credential=credential,
            paidTime=paidTime,
            refundTime=refundTime,
            expiryTime=expiryTime,
            settleTime=settleTime,
            createTime=createTime,
            _configuration=_configuration,
            **kwargs,
        )

from elepay.model.card_info import CardInfo
from elepay.model.charge_status_type import ChargeStatusType
from elepay.model.payment_method_type import PaymentMethodType
from elepay.model.refunds_dto import RefundsDto
from elepay.model.resource_type import ResourceType



# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from elepay.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from elepay.model.card_brand_type import CardBrandType
from elepay.model.card_info import CardInfo
from elepay.model.channel_properties_dto import ChannelPropertiesDto
from elepay.model.charge_capture_req import ChargeCaptureReq
from elepay.model.charge_date_time_type import ChargeDateTimeType
from elepay.model.charge_dto import ChargeDto
from elepay.model.charge_req import ChargeReq
from elepay.model.charge_status_dto import ChargeStatusDto
from elepay.model.charge_status_type import ChargeStatusType
from elepay.model.charges_response import ChargesResponse
from elepay.model.code_dto import CodeDto
from elepay.model.code_item import CodeItem
from elepay.model.code_payment_method_response import CodePaymentMethodResponse
from elepay.model.code_req import CodeReq
from elepay.model.code_status_type import CodeStatusType
from elepay.model.customer_dto import CustomerDto
from elepay.model.customer_properties_dto import CustomerPropertiesDto
from elepay.model.customer_req import CustomerReq
from elepay.model.customer_response import CustomerResponse
from elepay.model.customer_status_type import CustomerStatusType
from elepay.model.dispute_date_time_type import DisputeDateTimeType
from elepay.model.dispute_dto import DisputeDto
from elepay.model.dispute_status_type import DisputeStatusType
from elepay.model.disputes_response import DisputesResponse
from elepay.model.invoice_dto import InvoiceDto
from elepay.model.invoice_item import InvoiceItem
from elepay.model.invoice_req import InvoiceReq
from elepay.model.invoice_status_type import InvoiceStatusType
from elepay.model.invoices_response import InvoicesResponse
from elepay.model.location_dto import LocationDto
from elepay.model.locations_response import LocationsResponse
from elepay.model.payment_method_dto import PaymentMethodDto
from elepay.model.payment_method_response import PaymentMethodResponse
from elepay.model.payment_method_type import PaymentMethodType
from elepay.model.reader_status_type import ReaderStatusType
from elepay.model.refund_dto import RefundDto
from elepay.model.refund_req import RefundReq
from elepay.model.refund_status_type import RefundStatusType
from elepay.model.refunds_dto import RefundsDto
from elepay.model.refunds_response import RefundsResponse
from elepay.model.resource_type import ResourceType
from elepay.model.sort_order_type import SortOrderType
from elepay.model.source_dto import SourceDto
from elepay.model.source_req import SourceReq
from elepay.model.source_response import SourceResponse
from elepay.model.source_status_dto import SourceStatusDto
from elepay.model.source_status_type import SourceStatusType
from elepay.model.subscription_dto import SubscriptionDto
from elepay.model.subscription_interval_type import SubscriptionIntervalType
from elepay.model.subscription_period_dto import SubscriptionPeriodDto
from elepay.model.subscription_periods_response import SubscriptionPeriodsResponse
from elepay.model.subscription_req import SubscriptionReq
from elepay.model.subscription_schedule_charges_response import SubscriptionScheduleChargesResponse
from elepay.model.subscription_status_type import SubscriptionStatusType
from elepay.model.subscription_update_req import SubscriptionUpdateReq
from elepay.model.subscriptions_response import SubscriptionsResponse
from elepay.model.terminal_reader_dto import TerminalReaderDto
from elepay.model.terminal_reader_req import TerminalReaderReq
from elepay.model.terminal_readers_response import TerminalReadersResponse



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class PaymentMethodDto(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    決済方法詳細情報
    """


    class MetaOapg:
        
        class properties:
        
            @staticmethod
            def paymentMethod() -> typing.Type['PaymentMethodType']:
                return PaymentMethodType
            
            
            class resources(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['ResourceType']:
                        return ResourceType
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['ResourceType'], typing.List['ResourceType']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'resources':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'ResourceType':
                    return super().__getitem__(i)
            
            
            class brand(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'brand':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            ua = schemas.StrSchema
        
            @staticmethod
            def channelProperties() -> typing.Type['ChannelPropertiesDto']:
                return ChannelPropertiesDto
        
            @staticmethod
            def customerProperties() -> typing.Type['CustomerPropertiesDto']:
                return CustomerPropertiesDto
            __annotations__ = {
                "paymentMethod": paymentMethod,
                "resources": resources,
                "brand": brand,
                "ua": ua,
                "channelProperties": channelProperties,
                "customerProperties": customerProperties,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paymentMethod"]) -> 'PaymentMethodType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["resources"]) -> MetaOapg.properties.resources: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["brand"]) -> MetaOapg.properties.brand: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ua"]) -> MetaOapg.properties.ua: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["channelProperties"]) -> 'ChannelPropertiesDto': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customerProperties"]) -> 'CustomerPropertiesDto': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["paymentMethod", "resources", "brand", "ua", "channelProperties", "customerProperties", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paymentMethod"]) -> typing.Union['PaymentMethodType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["resources"]) -> typing.Union[MetaOapg.properties.resources, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["brand"]) -> typing.Union[MetaOapg.properties.brand, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ua"]) -> typing.Union[MetaOapg.properties.ua, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["channelProperties"]) -> typing.Union['ChannelPropertiesDto', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customerProperties"]) -> typing.Union['CustomerPropertiesDto', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["paymentMethod", "resources", "brand", "ua", "channelProperties", "customerProperties", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        paymentMethod: typing.Union['PaymentMethodType', schemas.Unset] = schemas.unset,
        resources: typing.Union[MetaOapg.properties.resources, list, tuple, schemas.Unset] = schemas.unset,
        brand: typing.Union[MetaOapg.properties.brand, list, tuple, schemas.Unset] = schemas.unset,
        ua: typing.Union[MetaOapg.properties.ua, str, schemas.Unset] = schemas.unset,
        channelProperties: typing.Union['ChannelPropertiesDto', schemas.Unset] = schemas.unset,
        customerProperties: typing.Union['CustomerPropertiesDto', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PaymentMethodDto':
        return super().__new__(
            cls,
            *args,
            paymentMethod=paymentMethod,
            resources=resources,
            brand=brand,
            ua=ua,
            channelProperties=channelProperties,
            customerProperties=customerProperties,
            _configuration=_configuration,
            **kwargs,
        )

from elepay.model.channel_properties_dto import ChannelPropertiesDto
from elepay.model.customer_properties_dto import CustomerPropertiesDto
from elepay.model.payment_method_type import PaymentMethodType
from elepay.model.resource_type import ResourceType



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from elepay.paths.disputes.get import ListDisputes
from elepay.paths.disputes_id.get import RetrieveDispute


class DisputeApi(
    ListDisputes,
    RetrieveDispute,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



import typing_extensions

from elepay.paths import PathValues
from elepay.apis.paths.charges import Charges
from elepay.apis.paths.charges_id import ChargesId
from elepay.apis.paths.charges_id_revoke import ChargesIdRevoke
from elepay.apis.paths.charges_id_capture import ChargesIdCapture
from elepay.apis.paths.charges_id_status import ChargesIdStatus
from elepay.apis.paths.charges_id_refunds import ChargesIdRefunds
from elepay.apis.paths.charges_id_refunds_refund_id import ChargesIdRefundsRefundId
from elepay.apis.paths.customers import Customers
from elepay.apis.paths.customers_customer_id import CustomersCustomerId
from elepay.apis.paths.customers_customer_id_sources import CustomersCustomerIdSources
from elepay.apis.paths.customers_customer_id_sources_source_id import CustomersCustomerIdSourcesSourceId
from elepay.apis.paths.sources_source_id_status import SourcesSourceIdStatus
from elepay.apis.paths.payment_methods import PaymentMethods
from elepay.apis.paths.codes import Codes
from elepay.apis.paths.codes_code_id import CodesCodeId
from elepay.apis.paths.code_setting_payment_methods import CodeSettingPaymentMethods
from elepay.apis.paths.invoices import Invoices
from elepay.apis.paths.invoices_invoice_id import InvoicesInvoiceId
from elepay.apis.paths.invoices_invoice_id_cancel import InvoicesInvoiceIdCancel
from elepay.apis.paths.invoices_invoice_id_submit import InvoicesInvoiceIdSubmit
from elepay.apis.paths.invoices_invoice_id_send import InvoicesInvoiceIdSend
from elepay.apis.paths.terminal_locations import TerminalLocations
from elepay.apis.paths.terminal_readers import TerminalReaders
from elepay.apis.paths.terminal_readers_reader_id import TerminalReadersReaderId
from elepay.apis.paths.disputes import Disputes
from elepay.apis.paths.disputes_id import DisputesId
from elepay.apis.paths.subscriptions import Subscriptions
from elepay.apis.paths.subscriptions_subscription_id import SubscriptionsSubscriptionId
from elepay.apis.paths.subscriptions_subscription_id_start import SubscriptionsSubscriptionIdStart
from elepay.apis.paths.subscriptions_subscription_id_resume import SubscriptionsSubscriptionIdResume
from elepay.apis.paths.subscriptions_subscription_id_cancel import SubscriptionsSubscriptionIdCancel
from elepay.apis.paths.subscriptions_subscription_id_periods import SubscriptionsSubscriptionIdPeriods

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.CHARGES: Charges,
        PathValues.CHARGES_ID: ChargesId,
        PathValues.CHARGES_ID_REVOKE: ChargesIdRevoke,
        PathValues.CHARGES_ID_CAPTURE: ChargesIdCapture,
        PathValues.CHARGES_ID_STATUS: ChargesIdStatus,
        PathValues.CHARGES_ID_REFUNDS: ChargesIdRefunds,
        PathValues.CHARGES_ID_REFUNDS_REFUND_ID: ChargesIdRefundsRefundId,
        PathValues.CUSTOMERS: Customers,
        PathValues.CUSTOMERS_CUSTOMER_ID: CustomersCustomerId,
        PathValues.CUSTOMERS_CUSTOMER_ID_SOURCES: CustomersCustomerIdSources,
        PathValues.CUSTOMERS_CUSTOMER_ID_SOURCES_SOURCE_ID: CustomersCustomerIdSourcesSourceId,
        PathValues.SOURCES_SOURCE_ID_STATUS: SourcesSourceIdStatus,
        PathValues.PAYMENTMETHODS: PaymentMethods,
        PathValues.CODES: Codes,
        PathValues.CODES_CODE_ID: CodesCodeId,
        PathValues.CODESETTING_PAYMENTMETHODS: CodeSettingPaymentMethods,
        PathValues.INVOICES: Invoices,
        PathValues.INVOICES_INVOICE_ID: InvoicesInvoiceId,
        PathValues.INVOICES_INVOICE_ID_CANCEL: InvoicesInvoiceIdCancel,
        PathValues.INVOICES_INVOICE_ID_SUBMIT: InvoicesInvoiceIdSubmit,
        PathValues.INVOICES_INVOICE_ID_SEND: InvoicesInvoiceIdSend,
        PathValues.TERMINAL_LOCATIONS: TerminalLocations,
        PathValues.TERMINAL_READERS: TerminalReaders,
        PathValues.TERMINAL_READERS_READER_ID: TerminalReadersReaderId,
        PathValues.DISPUTES: Disputes,
        PathValues.DISPUTES_ID: DisputesId,
        PathValues.SUBSCRIPTIONS: Subscriptions,
        PathValues.SUBSCRIPTIONS_SUBSCRIPTION_ID: SubscriptionsSubscriptionId,
        PathValues.SUBSCRIPTIONS_SUBSCRIPTION_ID_START: SubscriptionsSubscriptionIdStart,
        PathValues.SUBSCRIPTIONS_SUBSCRIPTION_ID_RESUME: SubscriptionsSubscriptionIdResume,
        PathValues.SUBSCRIPTIONS_SUBSCRIPTION_ID_CANCEL: SubscriptionsSubscriptionIdCancel,
        PathValues.SUBSCRIPTIONS_SUBSCRIPTION_ID_PERIODS: SubscriptionsSubscriptionIdPeriods,
    }
)

path_to_api = PathToApi(
    {
        PathValues.CHARGES: Charges,
        PathValues.CHARGES_ID: ChargesId,
        PathValues.CHARGES_ID_REVOKE: ChargesIdRevoke,
        PathValues.CHARGES_ID_CAPTURE: ChargesIdCapture,
        PathValues.CHARGES_ID_STATUS: ChargesIdStatus,
        PathValues.CHARGES_ID_REFUNDS: ChargesIdRefunds,
        PathValues.CHARGES_ID_REFUNDS_REFUND_ID: ChargesIdRefundsRefundId,
        PathValues.CUSTOMERS: Customers,
        PathValues.CUSTOMERS_CUSTOMER_ID: CustomersCustomerId,
        PathValues.CUSTOMERS_CUSTOMER_ID_SOURCES: CustomersCustomerIdSources,
        PathValues.CUSTOMERS_CUSTOMER_ID_SOURCES_SOURCE_ID: CustomersCustomerIdSourcesSourceId,
        PathValues.SOURCES_SOURCE_ID_STATUS: SourcesSourceIdStatus,
        PathValues.PAYMENTMETHODS: PaymentMethods,
        PathValues.CODES: Codes,
        PathValues.CODES_CODE_ID: CodesCodeId,
        PathValues.CODESETTING_PAYMENTMETHODS: CodeSettingPaymentMethods,
        PathValues.INVOICES: Invoices,
        PathValues.INVOICES_INVOICE_ID: InvoicesInvoiceId,
        PathValues.INVOICES_INVOICE_ID_CANCEL: InvoicesInvoiceIdCancel,
        PathValues.INVOICES_INVOICE_ID_SUBMIT: InvoicesInvoiceIdSubmit,
        PathValues.INVOICES_INVOICE_ID_SEND: InvoicesInvoiceIdSend,
        PathValues.TERMINAL_LOCATIONS: TerminalLocations,
        PathValues.TERMINAL_READERS: TerminalReaders,
        PathValues.TERMINAL_READERS_READER_ID: TerminalReadersReaderId,
        PathValues.DISPUTES: Disputes,
        PathValues.DISPUTES_ID: DisputesId,
        PathValues.SUBSCRIPTIONS: Subscriptions,
        PathValues.SUBSCRIPTIONS_SUBSCRIPTION_ID: SubscriptionsSubscriptionId,
        PathValues.SUBSCRIPTIONS_SUBSCRIPTION_ID_START: SubscriptionsSubscriptionIdStart,
        PathValues.SUBSCRIPTIONS_SUBSCRIPTION_ID_RESUME: SubscriptionsSubscriptionIdResume,
        PathValues.SUBSCRIPTIONS_SUBSCRIPTION_ID_CANCEL: SubscriptionsSubscriptionIdCancel,
        PathValues.SUBSCRIPTIONS_SUBSCRIPTION_ID_PERIODS: SubscriptionsSubscriptionIdPeriods,
    }
)



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class CodeReq(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    EasyQRコードリクエスト
    """


    class MetaOapg:
        required = {
            "amount",
            "orderNo",
        }
        
        class properties:
            amount = schemas.IntSchema
            orderNo = schemas.StrSchema
            currency = schemas.StrSchema
            description = schemas.StrSchema
            
            
            class extra(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'extra':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class metadata(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'metadata':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            expiryDuration = schemas.IntSchema
            
            
            class frontUrl(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    regex=[{
                        'pattern': r'https?://[-A-Za-z0-9+&@#/%?=~_|!:,.;]+[-A-Za-z0-9+&@#/%=~_|]',  # noqa: E501
                    }]
            
            
            class items(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['CodeItem']:
                        return CodeItem
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['CodeItem'], typing.List['CodeItem']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'items':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'CodeItem':
                    return super().__getitem__(i)
            __annotations__ = {
                "amount": amount,
                "orderNo": orderNo,
                "currency": currency,
                "description": description,
                "extra": extra,
                "metadata": metadata,
                "expiryDuration": expiryDuration,
                "frontUrl": frontUrl,
                "items": items,
            }
    
    amount: MetaOapg.properties.amount
    orderNo: MetaOapg.properties.orderNo
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["orderNo"]) -> MetaOapg.properties.orderNo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["extra"]) -> MetaOapg.properties.extra: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expiryDuration"]) -> MetaOapg.properties.expiryDuration: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["frontUrl"]) -> MetaOapg.properties.frontUrl: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["items"]) -> MetaOapg.properties.items: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["amount", "orderNo", "currency", "description", "extra", "metadata", "expiryDuration", "frontUrl", "items", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["orderNo"]) -> MetaOapg.properties.orderNo: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> typing.Union[MetaOapg.properties.currency, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["extra"]) -> typing.Union[MetaOapg.properties.extra, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expiryDuration"]) -> typing.Union[MetaOapg.properties.expiryDuration, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["frontUrl"]) -> typing.Union[MetaOapg.properties.frontUrl, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["items"]) -> typing.Union[MetaOapg.properties.items, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["amount", "orderNo", "currency", "description", "extra", "metadata", "expiryDuration", "frontUrl", "items", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, ],
        orderNo: typing.Union[MetaOapg.properties.orderNo, str, ],
        currency: typing.Union[MetaOapg.properties.currency, str, schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        extra: typing.Union[MetaOapg.properties.extra, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        expiryDuration: typing.Union[MetaOapg.properties.expiryDuration, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        frontUrl: typing.Union[MetaOapg.properties.frontUrl, str, schemas.Unset] = schemas.unset,
        items: typing.Union[MetaOapg.properties.items, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CodeReq':
        return super().__new__(
            cls,
            *args,
            amount=amount,
            orderNo=orderNo,
            currency=currency,
            description=description,
            extra=extra,
            metadata=metadata,
            expiryDuration=expiryDuration,
            frontUrl=frontUrl,
            items=items,
            _configuration=_configuration,
            **kwargs,
        )

from elepay.model.code_item import CodeItem



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class SubscriptionIntervalType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    定期課金周期タイプ
- day １日１回
- week 週１回
- month 月１回
- year 年１回

    """


    class MetaOapg:
        enum_value_to_name = {
            "day": "DAY",
            "week": "WEEK",
            "month": "MONTH",
            "year": "YEAR",
        }
    
    @schemas.classproperty
    def DAY(cls):
        return cls("day")
    
    @schemas.classproperty
    def WEEK(cls):
        return cls("week")
    
    @schemas.classproperty
    def MONTH(cls):
        return cls("month")
    
    @schemas.classproperty
    def YEAR(cls):
        return cls("year")



from elepay.paths.invoices_invoice_id.get import ApiForget
from elepay.paths.invoices_invoice_id.post import ApiForpost
from elepay.paths.invoices_invoice_id.delete import ApiFordelete


class InvoicesInvoiceId(
    ApiForget,
    ApiForpost,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class CodeDto(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    EasyQRコードオブジェクト
    """


    class MetaOapg:
        
        class properties:
            id = schemas.StrSchema
            object = schemas.StrSchema
            liveMode = schemas.BoolSchema
            codeUrl = schemas.StrSchema
            amount = schemas.IntSchema
            currency = schemas.StrSchema
            orderNo = schemas.StrSchema
            description = schemas.StrSchema
            
            
            class extra(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'extra':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class metadata(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'metadata':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
        
            @staticmethod
            def status() -> typing.Type['CodeStatusType']:
                return CodeStatusType
        
            @staticmethod
            def charge() -> typing.Type['ChargeDto']:
                return ChargeDto
            frontUrl = schemas.StrSchema
            
            
            class items(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['CodeItem']:
                        return CodeItem
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['CodeItem'], typing.List['CodeItem']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'items':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'CodeItem':
                    return super().__getitem__(i)
            expired = schemas.BoolSchema
            expiryTime = schemas.Int64Schema
            expiryPeriod = schemas.Int64Schema
            createTime = schemas.Int64Schema
            __annotations__ = {
                "id": id,
                "object": object,
                "liveMode": liveMode,
                "codeUrl": codeUrl,
                "amount": amount,
                "currency": currency,
                "orderNo": orderNo,
                "description": description,
                "extra": extra,
                "metadata": metadata,
                "status": status,
                "charge": charge,
                "frontUrl": frontUrl,
                "items": items,
                "expired": expired,
                "expiryTime": expiryTime,
                "expiryPeriod": expiryPeriod,
                "createTime": createTime,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["object"]) -> MetaOapg.properties.object: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["liveMode"]) -> MetaOapg.properties.liveMode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["codeUrl"]) -> MetaOapg.properties.codeUrl: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["orderNo"]) -> MetaOapg.properties.orderNo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["extra"]) -> MetaOapg.properties.extra: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'CodeStatusType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["charge"]) -> 'ChargeDto': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["frontUrl"]) -> MetaOapg.properties.frontUrl: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["items"]) -> MetaOapg.properties.items: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expired"]) -> MetaOapg.properties.expired: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expiryTime"]) -> MetaOapg.properties.expiryTime: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expiryPeriod"]) -> MetaOapg.properties.expiryPeriod: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createTime"]) -> MetaOapg.properties.createTime: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "object", "liveMode", "codeUrl", "amount", "currency", "orderNo", "description", "extra", "metadata", "status", "charge", "frontUrl", "items", "expired", "expiryTime", "expiryPeriod", "createTime", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["object"]) -> typing.Union[MetaOapg.properties.object, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["liveMode"]) -> typing.Union[MetaOapg.properties.liveMode, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["codeUrl"]) -> typing.Union[MetaOapg.properties.codeUrl, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> typing.Union[MetaOapg.properties.amount, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> typing.Union[MetaOapg.properties.currency, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["orderNo"]) -> typing.Union[MetaOapg.properties.orderNo, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["extra"]) -> typing.Union[MetaOapg.properties.extra, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union['CodeStatusType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["charge"]) -> typing.Union['ChargeDto', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["frontUrl"]) -> typing.Union[MetaOapg.properties.frontUrl, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["items"]) -> typing.Union[MetaOapg.properties.items, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expired"]) -> typing.Union[MetaOapg.properties.expired, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expiryTime"]) -> typing.Union[MetaOapg.properties.expiryTime, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expiryPeriod"]) -> typing.Union[MetaOapg.properties.expiryPeriod, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createTime"]) -> typing.Union[MetaOapg.properties.createTime, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "object", "liveMode", "codeUrl", "amount", "currency", "orderNo", "description", "extra", "metadata", "status", "charge", "frontUrl", "items", "expired", "expiryTime", "expiryPeriod", "createTime", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
        object: typing.Union[MetaOapg.properties.object, str, schemas.Unset] = schemas.unset,
        liveMode: typing.Union[MetaOapg.properties.liveMode, bool, schemas.Unset] = schemas.unset,
        codeUrl: typing.Union[MetaOapg.properties.codeUrl, str, schemas.Unset] = schemas.unset,
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        currency: typing.Union[MetaOapg.properties.currency, str, schemas.Unset] = schemas.unset,
        orderNo: typing.Union[MetaOapg.properties.orderNo, str, schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        extra: typing.Union[MetaOapg.properties.extra, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        status: typing.Union['CodeStatusType', schemas.Unset] = schemas.unset,
        charge: typing.Union['ChargeDto', schemas.Unset] = schemas.unset,
        frontUrl: typing.Union[MetaOapg.properties.frontUrl, str, schemas.Unset] = schemas.unset,
        items: typing.Union[MetaOapg.properties.items, list, tuple, schemas.Unset] = schemas.unset,
        expired: typing.Union[MetaOapg.properties.expired, bool, schemas.Unset] = schemas.unset,
        expiryTime: typing.Union[MetaOapg.properties.expiryTime, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        expiryPeriod: typing.Union[MetaOapg.properties.expiryPeriod, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        createTime: typing.Union[MetaOapg.properties.createTime, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CodeDto':
        return super().__new__(
            cls,
            *args,
            id=id,
            object=object,
            liveMode=liveMode,
            codeUrl=codeUrl,
            amount=amount,
            currency=currency,
            orderNo=orderNo,
            description=description,
            extra=extra,
            metadata=metadata,
            status=status,
            charge=charge,
            frontUrl=frontUrl,
            items=items,
            expired=expired,
            expiryTime=expiryTime,
            expiryPeriod=expiryPeriod,
            createTime=createTime,
            _configuration=_configuration,
            **kwargs,
        )

from elepay.model.charge_dto import ChargeDto
from elepay.model.code_item import CodeItem
from elepay.model.code_status_type import CodeStatusType



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class InvoiceStatusType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    インボイス状態

    """


    class MetaOapg:
        enum_value_to_name = {
            "draft": "DRAFT",
            "submit": "SUBMIT",
            "sent": "SENT",
            "paid": "PAID",
            "expired": "EXPIRED",
            "canceled": "CANCELED",
        }
    
    @schemas.classproperty
    def DRAFT(cls):
        return cls("draft")
    
    @schemas.classproperty
    def SUBMIT(cls):
        return cls("submit")
    
    @schemas.classproperty
    def SENT(cls):
        return cls("sent")
    
    @schemas.classproperty
    def PAID(cls):
        return cls("paid")
    
    @schemas.classproperty
    def EXPIRED(cls):
        return cls("expired")
    
    @schemas.classproperty
    def CANCELED(cls):
        return cls("canceled")



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class InvoiceItem(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    インボイスオブジェクト
    """


    class MetaOapg:
        
        class properties:
            id = schemas.StrSchema
            object = schemas.StrSchema
            name = schemas.StrSchema
            unitPrice = schemas.IntSchema
            currency = schemas.StrSchema
            quantity = schemas.IntSchema
            __annotations__ = {
                "id": id,
                "object": object,
                "name": name,
                "unitPrice": unitPrice,
                "currency": currency,
                "quantity": quantity,
            }

    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["object"]) -> MetaOapg.properties.object: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["unitPrice"]) -> MetaOapg.properties.unitPrice: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["quantity"]) -> MetaOapg.properties.quantity: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "object", "name", "unitPrice", "currency", "quantity", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["object"]) -> typing.Union[MetaOapg.properties.object, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["unitPrice"]) -> typing.Union[MetaOapg.properties.unitPrice, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> typing.Union[MetaOapg.properties.currency, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["quantity"]) -> typing.Union[MetaOapg.properties.quantity, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "object", "name", "unitPrice", "currency", "quantity", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
        object: typing.Union[MetaOapg.properties.object, str, schemas.Unset] = schemas.unset,
        name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
        unitPrice: typing.Union[MetaOapg.properties.unitPrice, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        currency: typing.Union[MetaOapg.properties.currency, str, schemas.Unset] = schemas.unset,
        quantity: typing.Union[MetaOapg.properties.quantity, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'InvoiceItem':
        return super().__new__(
            cls,
            *args,
            id=id,
            object=object,
            name=name,
            unitPrice=unitPrice,
            currency=currency,
            quantity=quantity,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from elepay.paths.charges_id_refunds.post import CreateRefund
from elepay.paths.charges_id_refunds.get import ListChargesRefunds
from elepay.paths.charges_id_refunds_refund_id.get import RetrieveChargeRefund


class RefundApi(
    CreateRefund,
    ListChargesRefunds,
    RetrieveChargeRefund,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from elepay.paths.customers_customer_id_sources.get import ApiForget
from elepay.paths.customers_customer_id_sources.post import ApiForpost


class CustomersCustomerIdSources(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class RefundReq(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    返金リクエスト
    """


    class MetaOapg:
        required = {
            "amount",
        }
        
        class properties:
            amount = schemas.IntSchema
            currency = schemas.StrSchema
            
            
            class metadata(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'metadata':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            reason = schemas.StrSchema
            __annotations__ = {
                "amount": amount,
                "currency": currency,
                "metadata": metadata,
                "reason": reason,
            }
    
    amount: MetaOapg.properties.amount
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["reason"]) -> MetaOapg.properties.reason: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["amount", "currency", "metadata", "reason", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> typing.Union[MetaOapg.properties.currency, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["reason"]) -> typing.Union[MetaOapg.properties.reason, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["amount", "currency", "metadata", "reason", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, ],
        currency: typing.Union[MetaOapg.properties.currency, str, schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        reason: typing.Union[MetaOapg.properties.reason, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'RefundReq':
        return super().__new__(
            cls,
            *args,
            amount=amount,
            currency=currency,
            metadata=metadata,
            reason=reason,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class SubscriptionPeriodsResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    定期課金周期情報リスト
    """


    class MetaOapg:
        
        class properties:
            total = schemas.IntSchema
            
            
            class periods(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['SubscriptionPeriodDto']:
                        return SubscriptionPeriodDto
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['SubscriptionPeriodDto'], typing.List['SubscriptionPeriodDto']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'periods':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'SubscriptionPeriodDto':
                    return super().__getitem__(i)
            __annotations__ = {
                "total": total,
                "periods": periods,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["periods"]) -> MetaOapg.properties.periods: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["total", "periods", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["total"]) -> typing.Union[MetaOapg.properties.total, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["periods"]) -> typing.Union[MetaOapg.properties.periods, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["total", "periods", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        total: typing.Union[MetaOapg.properties.total, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        periods: typing.Union[MetaOapg.properties.periods, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SubscriptionPeriodsResponse':
        return super().__new__(
            cls,
            *args,
            total=total,
            periods=periods,
            _configuration=_configuration,
            **kwargs,
        )

from elepay.model.subscription_period_dto import SubscriptionPeriodDto



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "elepay-python-sdk"
VERSION = "1.2.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi >= 14.5.14",
    "frozendict ~= 2.3.4",
    "python-dateutil ~= 2.7.0",
    "setuptools >= 21.0.0",
    "typing_extensions ~= 4.3.0",
    "urllib3 ~= 1.26.7",
]

with open('README.md', 'r') as readme:
    setup(
        name=NAME,
        version=VERSION,
        description="elepay API リファレンス",
        author="ELESTYLE, INC",
        author_email="support@elestyle.jp",
        url="https://github.com/elestyle/elepay-python-sdk",
        keywords=["restful", "elepay API リファレンス"],
        python_requires=">=3.7",
        install_requires=REQUIRES,
        packages=find_packages(exclude=["test", "tests"]),
        include_package_data=True,
        long_description_content_type="text/markdown",
        long_description=readme.read()
    )



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class SubscriptionDto(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    定期課金オブジェクト
    """


    class MetaOapg:
        
        class properties:
            id = schemas.StrSchema
            appId = schemas.StrSchema
            object = schemas.StrSchema
            liveMode = schemas.BoolSchema
            customerId = schemas.StrSchema
        
            @staticmethod
            def customer() -> typing.Type['CustomerDto']:
                return CustomerDto
            nextChargeTime = schemas.Int64Schema
            isCharging = schemas.BoolSchema
            chargedPeriods = schemas.IntSchema
            
            
            class metadata(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'metadata':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
        
            @staticmethod
            def status() -> typing.Type['SubscriptionStatusType']:
                return SubscriptionStatusType
            createTime = schemas.Int64Schema
            updateTime = schemas.Int64Schema
            __annotations__ = {
                "id": id,
                "appId": appId,
                "object": object,
                "liveMode": liveMode,
                "customerId": customerId,
                "customer": customer,
                "nextChargeTime": nextChargeTime,
                "isCharging": isCharging,
                "chargedPeriods": chargedPeriods,
                "metadata": metadata,
                "status": status,
                "createTime": createTime,
                "updateTime": updateTime,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["appId"]) -> MetaOapg.properties.appId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["object"]) -> MetaOapg.properties.object: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["liveMode"]) -> MetaOapg.properties.liveMode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customerId"]) -> MetaOapg.properties.customerId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customer"]) -> 'CustomerDto': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nextChargeTime"]) -> MetaOapg.properties.nextChargeTime: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["isCharging"]) -> MetaOapg.properties.isCharging: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["chargedPeriods"]) -> MetaOapg.properties.chargedPeriods: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'SubscriptionStatusType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createTime"]) -> MetaOapg.properties.createTime: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateTime"]) -> MetaOapg.properties.updateTime: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "appId", "object", "liveMode", "customerId", "customer", "nextChargeTime", "isCharging", "chargedPeriods", "metadata", "status", "createTime", "updateTime", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["appId"]) -> typing.Union[MetaOapg.properties.appId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["object"]) -> typing.Union[MetaOapg.properties.object, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["liveMode"]) -> typing.Union[MetaOapg.properties.liveMode, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customerId"]) -> typing.Union[MetaOapg.properties.customerId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customer"]) -> typing.Union['CustomerDto', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nextChargeTime"]) -> typing.Union[MetaOapg.properties.nextChargeTime, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["isCharging"]) -> typing.Union[MetaOapg.properties.isCharging, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["chargedPeriods"]) -> typing.Union[MetaOapg.properties.chargedPeriods, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union['SubscriptionStatusType', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createTime"]) -> typing.Union[MetaOapg.properties.createTime, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateTime"]) -> typing.Union[MetaOapg.properties.updateTime, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "appId", "object", "liveMode", "customerId", "customer", "nextChargeTime", "isCharging", "chargedPeriods", "metadata", "status", "createTime", "updateTime", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
        appId: typing.Union[MetaOapg.properties.appId, str, schemas.Unset] = schemas.unset,
        object: typing.Union[MetaOapg.properties.object, str, schemas.Unset] = schemas.unset,
        liveMode: typing.Union[MetaOapg.properties.liveMode, bool, schemas.Unset] = schemas.unset,
        customerId: typing.Union[MetaOapg.properties.customerId, str, schemas.Unset] = schemas.unset,
        customer: typing.Union['CustomerDto', schemas.Unset] = schemas.unset,
        nextChargeTime: typing.Union[MetaOapg.properties.nextChargeTime, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        isCharging: typing.Union[MetaOapg.properties.isCharging, bool, schemas.Unset] = schemas.unset,
        chargedPeriods: typing.Union[MetaOapg.properties.chargedPeriods, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        status: typing.Union['SubscriptionStatusType', schemas.Unset] = schemas.unset,
        createTime: typing.Union[MetaOapg.properties.createTime, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        updateTime: typing.Union[MetaOapg.properties.updateTime, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SubscriptionDto':
        return super().__new__(
            cls,
            *args,
            id=id,
            appId=appId,
            object=object,
            liveMode=liveMode,
            customerId=customerId,
            customer=customer,
            nextChargeTime=nextChargeTime,
            isCharging=isCharging,
            chargedPeriods=chargedPeriods,
            metadata=metadata,
            status=status,
            createTime=createTime,
            updateTime=updateTime,
            _configuration=_configuration,
            **kwargs,
        )

from elepay.model.customer_dto import CustomerDto
from elepay.model.subscription_status_type import SubscriptionStatusType



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from elepay.paths.invoices_invoice_id_cancel.post import CancelInvoice
from elepay.paths.invoices.post import CreateInvoice
from elepay.paths.invoices_invoice_id.delete import DeleteInvoice
from elepay.paths.invoices.get import ListInvoices
from elepay.paths.invoices_invoice_id.get import RetrieveInvoice
from elepay.paths.invoices_invoice_id_send.post import SendInvoice
from elepay.paths.invoices_invoice_id_submit.post import SubmitInvoice
from elepay.paths.invoices_invoice_id.post import UpdateInvoice


class InvoiceApi(
    CancelInvoice,
    CreateInvoice,
    DeleteInvoice,
    ListInvoices,
    RetrieveInvoice,
    SendInvoice,
    SubmitInvoice,
    UpdateInvoice,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

# flake8: noqa

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

__version__ = "1.2.0"

# import ApiClient
from elepay.api_client import ApiClient

# import Configuration
from elepay.configuration import Configuration

# import exceptions
from elepay.exceptions import OpenApiException
from elepay.exceptions import ApiAttributeError
from elepay.exceptions import ApiTypeError
from elepay.exceptions import ApiValueError
from elepay.exceptions import ApiKeyError
from elepay.exceptions import ApiException



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class PaymentMethodType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    決済方法
- auto 自動識別(CPM決済のみ利用可能)
- alipay アリペイ
- alipayhk アリペイHK
- alipayplus Alipay+
- amazonpay Amazon Pay
- applepay Apple Pay
- applepay_cn Apple Pay(中国)
- atone atone(コンビニで翌月払い)
- aupay au Pay
- creditcard クレジットカード
- dana DANA
- docomopay d払い
- ezlink EZ-Link
- felica_id iD
- felica_quickpay QUICPay
- felica_transport_ic 交通系ICカード
- gcash GCash
- ginkopay 銀行Pay
- googlepay Google Pay
- jcoinpay J-Coin Pay
- jkopay JKOPAY
- kakaopay Kakao Pay
- linepay LINE Pay
- merpay メルペイ
- origamipay Origami Pay
- paidy Paidy 翌月払い
- paypal PayPal
- paypay PayPay
- rakutenpay 楽天ペイ
- tng Touch 'n Go eWallet
- truemoney TrueMoney
- unionpay 雲閃付
- wechatpay Wechat Pay

    """


    class MetaOapg:
        enum_value_to_name = {
            "alipay": "ALIPAY",
            "alipayhk": "ALIPAYHK",
            "alipayplus": "ALIPAYPLUS",
            "amazonpay": "AMAZONPAY",
            "applepay": "APPLEPAY",
            "applepay_cn": "APPLEPAY_CN",
            "atone": "ATONE",
            "aupay": "AUPAY",
            "creditcard": "CREDITCARD",
            "dana": "DANA",
            "docomopay": "DOCOMOPAY",
            "ezlink": "EZLINK",
            "felica_id": "FELICA_ID",
            "felica_quickpay": "FELICA_QUICKPAY",
            "felica_transport_ic": "FELICA_TRANSPORT_IC",
            "gcash": "GCASH",
            "ginkopay": "GINKOPAY",
            "googlepay": "GOOGLEPAY",
            "jcoinpay": "JCOINPAY",
            "jkopay": "JKOPAY",
            "kakaopay": "KAKAOPAY",
            "linepay": "LINEPAY",
            "merpay": "MERPAY",
            "origamipay": "ORIGAMIPAY",
            "paidy": "PAIDY",
            "paypal": "PAYPAL",
            "paypay": "PAYPAY",
            "rakutenpay": "RAKUTENPAY",
            "tng": "TNG",
            "truemoney": "TRUEMONEY",
            "unionpay": "UNIONPAY",
            "wechatpay": "WECHATPAY",
            "auto": "AUTO",
        }
    
    @schemas.classproperty
    def ALIPAY(cls):
        return cls("alipay")
    
    @schemas.classproperty
    def ALIPAYHK(cls):
        return cls("alipayhk")
    
    @schemas.classproperty
    def ALIPAYPLUS(cls):
        return cls("alipayplus")
    
    @schemas.classproperty
    def AMAZONPAY(cls):
        return cls("amazonpay")
    
    @schemas.classproperty
    def APPLEPAY(cls):
        return cls("applepay")
    
    @schemas.classproperty
    def APPLEPAY_CN(cls):
        return cls("applepay_cn")
    
    @schemas.classproperty
    def ATONE(cls):
        return cls("atone")
    
    @schemas.classproperty
    def AUPAY(cls):
        return cls("aupay")
    
    @schemas.classproperty
    def CREDITCARD(cls):
        return cls("creditcard")
    
    @schemas.classproperty
    def DANA(cls):
        return cls("dana")
    
    @schemas.classproperty
    def DOCOMOPAY(cls):
        return cls("docomopay")
    
    @schemas.classproperty
    def EZLINK(cls):
        return cls("ezlink")
    
    @schemas.classproperty
    def FELICA_ID(cls):
        return cls("felica_id")
    
    @schemas.classproperty
    def FELICA_QUICKPAY(cls):
        return cls("felica_quickpay")
    
    @schemas.classproperty
    def FELICA_TRANSPORT_IC(cls):
        return cls("felica_transport_ic")
    
    @schemas.classproperty
    def GCASH(cls):
        return cls("gcash")
    
    @schemas.classproperty
    def GINKOPAY(cls):
        return cls("ginkopay")
    
    @schemas.classproperty
    def GOOGLEPAY(cls):
        return cls("googlepay")
    
    @schemas.classproperty
    def JCOINPAY(cls):
        return cls("jcoinpay")
    
    @schemas.classproperty
    def JKOPAY(cls):
        return cls("jkopay")
    
    @schemas.classproperty
    def KAKAOPAY(cls):
        return cls("kakaopay")
    
    @schemas.classproperty
    def LINEPAY(cls):
        return cls("linepay")
    
    @schemas.classproperty
    def MERPAY(cls):
        return cls("merpay")
    
    @schemas.classproperty
    def ORIGAMIPAY(cls):
        return cls("origamipay")
    
    @schemas.classproperty
    def PAIDY(cls):
        return cls("paidy")
    
    @schemas.classproperty
    def PAYPAL(cls):
        return cls("paypal")
    
    @schemas.classproperty
    def PAYPAY(cls):
        return cls("paypay")
    
    @schemas.classproperty
    def RAKUTENPAY(cls):
        return cls("rakutenpay")
    
    @schemas.classproperty
    def TNG(cls):
        return cls("tng")
    
    @schemas.classproperty
    def TRUEMONEY(cls):
        return cls("truemoney")
    
    @schemas.classproperty
    def UNIONPAY(cls):
        return cls("unionpay")
    
    @schemas.classproperty
    def WECHATPAY(cls):
        return cls("wechatpay")
    
    @schemas.classproperty
    def AUTO(cls):
        return cls("auto")



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class InvoiceReq(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    インボイスリクエスト
    """


    class MetaOapg:
        
        class properties:
            name = schemas.StrSchema
            memo = schemas.StrSchema
            customerId = schemas.StrSchema
            amount = schemas.IntSchema
            currency = schemas.StrSchema
            expiryTime = schemas.Int64Schema
            
            
            class items(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['InvoiceItem']:
                        return InvoiceItem
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['InvoiceItem'], typing.List['InvoiceItem']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'items':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'InvoiceItem':
                    return super().__getitem__(i)
            remark = schemas.StrSchema
            
            
            class metadata(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'metadata':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "name": name,
                "memo": memo,
                "customerId": customerId,
                "amount": amount,
                "currency": currency,
                "expiryTime": expiryTime,
                "items": items,
                "remark": remark,
                "metadata": metadata,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["memo"]) -> MetaOapg.properties.memo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["customerId"]) -> MetaOapg.properties.customerId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["currency"]) -> MetaOapg.properties.currency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expiryTime"]) -> MetaOapg.properties.expiryTime: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["items"]) -> MetaOapg.properties.items: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["remark"]) -> MetaOapg.properties.remark: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> MetaOapg.properties.metadata: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "memo", "customerId", "amount", "currency", "expiryTime", "items", "remark", "metadata", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["memo"]) -> typing.Union[MetaOapg.properties.memo, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["customerId"]) -> typing.Union[MetaOapg.properties.customerId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> typing.Union[MetaOapg.properties.amount, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["currency"]) -> typing.Union[MetaOapg.properties.currency, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expiryTime"]) -> typing.Union[MetaOapg.properties.expiryTime, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["items"]) -> typing.Union[MetaOapg.properties.items, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["remark"]) -> typing.Union[MetaOapg.properties.remark, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union[MetaOapg.properties.metadata, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "memo", "customerId", "amount", "currency", "expiryTime", "items", "remark", "metadata", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
        memo: typing.Union[MetaOapg.properties.memo, str, schemas.Unset] = schemas.unset,
        customerId: typing.Union[MetaOapg.properties.customerId, str, schemas.Unset] = schemas.unset,
        amount: typing.Union[MetaOapg.properties.amount, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        currency: typing.Union[MetaOapg.properties.currency, str, schemas.Unset] = schemas.unset,
        expiryTime: typing.Union[MetaOapg.properties.expiryTime, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        items: typing.Union[MetaOapg.properties.items, list, tuple, schemas.Unset] = schemas.unset,
        remark: typing.Union[MetaOapg.properties.remark, str, schemas.Unset] = schemas.unset,
        metadata: typing.Union[MetaOapg.properties.metadata, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'InvoiceReq':
        return super().__new__(
            cls,
            *args,
            name=name,
            memo=memo,
            customerId=customerId,
            amount=amount,
            currency=currency,
            expiryTime=expiryTime,
            items=items,
            remark=remark,
            metadata=metadata,
            _configuration=_configuration,
            **kwargs,
        )

from elepay.model.invoice_item import InvoiceItem



# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from elepay.paths.customers.post import CreateCustomer
from elepay.paths.customers_customer_id_sources.post import CreateSource
from elepay.paths.customers_customer_id.delete import DeleteCustomer
from elepay.paths.customers_customer_id_sources_source_id.delete import DeleteSource
from elepay.paths.customers.get import ListCustomers
from elepay.paths.customers_customer_id_sources.get import ListSources
from elepay.paths.customers_customer_id.get import RetrieveCustomer
from elepay.paths.customers_customer_id_sources_source_id.get import RetrieveSource
from elepay.paths.sources_source_id_status.get import RetrieveSourceStatus
from elepay.paths.customers_customer_id.post import UpdateCustomer


class CustomerApi(
    CreateCustomer,
    CreateSource,
    DeleteCustomer,
    DeleteSource,
    ListCustomers,
    ListSources,
    RetrieveCustomer,
    RetrieveSource,
    RetrieveSourceStatus,
    UpdateCustomer,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
